# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`sudo`](#sudo): Constructs a sudoers file based on configured aliases, defaults, and user specifications.

### Defined types

* [`sudo::alias`](#sudo--alias): Adds an alias to /etc/sudoers. See the 'Aliases' section of sudoers (5) for information about aliases    Use the alias definition:     alias 
* [`sudo::alias::cmnd`](#sudo--alias--cmnd): Convenience definition for adding a cmnd alias.
* [`sudo::alias::host`](#sudo--alias--host): Convenience definition for adding a host alias.
* [`sudo::alias::runas`](#sudo--alias--runas): Convenience definition for adding a runas alias.
* [`sudo::alias::user`](#sudo--alias--user): Convenience definition for adding a user alias.
* [`sudo::default_entry`](#sudo--default_entry): Adds an entry to the defaults section of /etc/sudoers in order to override runtime defaults. See the 'Defaults' section of sudoers(5) for mor
* [`sudo::include_dir`](#sudo--include_dir): Add include directories to /etc/sudoers
* [`sudo::user_specification`](#sudo--user_specification): Add a user_spec entry to /etc/sudoers in order to determine which commands a user may run as the given user on the given host. See the 'User 

### Functions

* [`sudo::update_runas_list`](#sudo--update_runas_list): This function is used to help mitigate CVE-2019-14287 for  sudo version prior to 1.8.28.  It will disallow userid/groupid  of -1 if ALL or %A

### Data types

* [`Sudo::AliasType`](#Sudo--AliasType): Matches the list of configuration items for which aliases can be set in the sudeors file.
* [`Sudo::DefType`](#Sudo--DefType): Matches the list configuration items for which  defaults can be set in the sudoers file.

## Classes

### <a name="sudo"></a>`sudo`

Constructs a sudoers file based on configured aliases, defaults, and user
specifications.

#### Parameters

The following parameters are available in the `sudo` class:

* [`user_specifications`](#-sudo--user_specifications)
* [`include_dirs`](#-sudo--include_dirs)
* [`package_ensure`](#-sudo--package_ensure)
* [`default_entries`](#-sudo--default_entries)
* [`aliases`](#-sudo--aliases)

##### <a name="-sudo--user_specifications"></a>`user_specifications`

Data type: `Hash`

A hash of sudo::user_specification resources that can be set in hiera
Example:
  ---
  sudo::user_specifications:
    simp_su:
      user_list: ['simp']
      cmnd: ['/bin/su']
    users_yum_update:
      user_list:
        - '%users'
      cmnd:
        - 'yum update'
    test_resource:
      user_list: ['%group']
      cmnd: ['w']
      runas: root
      passwd: true

Default value: `{}`

##### <a name="-sudo--include_dirs"></a>`include_dirs`

Data type: `Array[Stdlib::Absolutepath]`

an array of paths to include in the sudoers file

Default value: `[]`

##### <a name="-sudo--package_ensure"></a>`package_ensure`

Data type: `String`

The ensure status of packages to be managed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-sudo--default_entries"></a>`default_entries`

Data type: `Hash`



Default value: `{}`

##### <a name="-sudo--aliases"></a>`aliases`

Data type: `Hash`



Default value: `{}`

## Defined types

### <a name="sudo--alias"></a>`sudo::alias`

Adds an alias to /etc/sudoers.
See the 'Aliases' section of sudoers (5) for information about aliases

  Use the alias definition:
    alias { 'user_alias':
      content => [ 'millert','mikef','dowdy' ],
      alias_type => 'user'
    }

#### Examples

##### To create the following alias in sudoers:

```puppet
User_Alias FULLTIMERS = millert, mikef, dowdy
```

#### Parameters

The following parameters are available in the `sudo::alias` defined type:

* [`content`](#-sudo--alias--content)
* [`alias_type`](#-sudo--alias--alias_type)
* [`comment`](#-sudo--alias--comment)
* [`order`](#-sudo--alias--order)

##### <a name="-sudo--alias--content"></a>`content`

Data type: `Array[String[1]]`

The array of items that will be the content of this alias.
For example: 'administrators', 'wheel'

##### <a name="-sudo--alias--alias_type"></a>`alias_type`

Data type: `Sudo::AliasType`

The type of alias to create.  One of 'user', 'runas', 'host' or 'cmnd'

##### <a name="-sudo--alias--comment"></a>`comment`

Data type: `Optional[String[1]]`

Textual comment for this entry

Default value: `undef`

##### <a name="-sudo--alias--order"></a>`order`

Data type: `Integer`

If desired, force the order of this entry relative to other entries.
Usually not required.

Default value: `10`

### <a name="sudo--alias--cmnd"></a>`sudo::alias::cmnd`

Convenience definition for adding a cmnd alias.

#### Parameters

The following parameters are available in the `sudo::alias::cmnd` defined type:

* [`content`](#-sudo--alias--cmnd--content)
* [`comment`](#-sudo--alias--cmnd--comment)
* [`order`](#-sudo--alias--cmnd--order)

##### <a name="-sudo--alias--cmnd--content"></a>`content`

Data type: `Array[String[1]]`

A comma-separated list of commands that will comprise this alias.
For example: ['/usr/sbin/shutdown', '/usr/sbin/reboot']

##### <a name="-sudo--alias--cmnd--comment"></a>`comment`

Data type: `Optional[String[1]]`

Textual comment for this entry.

Default value: `undef`

##### <a name="-sudo--alias--cmnd--order"></a>`order`

Data type: `Integer`

If desired, force the order of this entry relative to other entries.
Usually not required.

Default value: `10`

### <a name="sudo--alias--host"></a>`sudo::alias::host`

Convenience definition for adding a host alias.

#### Parameters

The following parameters are available in the `sudo::alias::host` defined type:

* [`content`](#-sudo--alias--host--content)
* [`comment`](#-sudo--alias--host--comment)
* [`order`](#-sudo--alias--host--order)

##### <a name="-sudo--alias--host--content"></a>`content`

Data type: `Array[String[1]]`

A comma-separated list of hostnames or IP addresses that will comprise the
alias.
For example: ['1.2.3.4', '5.6.7.8'] or ['mail', 'www']

##### <a name="-sudo--alias--host--comment"></a>`comment`

Data type: `Optional[String[1]]`

Textual comment for this entry

Default value: `undef`

##### <a name="-sudo--alias--host--order"></a>`order`

Data type: `Integer`

If desired, force the order of this entry relative to other entries.
Usually not required.

Default value: `12`

### <a name="sudo--alias--runas"></a>`sudo::alias::runas`

Convenience definition for adding a runas alias.

#### Parameters

The following parameters are available in the `sudo::alias::runas` defined type:

* [`content`](#-sudo--alias--runas--content)
* [`comment`](#-sudo--alias--runas--comment)
* [`order`](#-sudo--alias--runas--order)

##### <a name="-sudo--alias--runas--content"></a>`content`

Data type: `Array[String[1]]`

A comma-separated list of hostnames or IP addresses that will comprise the alias.
For example: ['millert', 'mikef']

##### <a name="-sudo--alias--runas--comment"></a>`comment`

Data type: `Optional[String[1]]`

Textual comment for this entry

Default value: `undef`

##### <a name="-sudo--alias--runas--order"></a>`order`

Data type: `Integer`

If desired, force the order of this entry relative to other entries.
Usually not required.

Default value: `14`

### <a name="sudo--alias--user"></a>`sudo::alias::user`

Convenience definition for adding a user alias.

#### Parameters

The following parameters are available in the `sudo::alias::user` defined type:

* [`content`](#-sudo--alias--user--content)
* [`comment`](#-sudo--alias--user--comment)
* [`order`](#-sudo--alias--user--order)

##### <a name="-sudo--alias--user--content"></a>`content`

Data type: `Array[String[1]]`

A comma-separated list of users that will comprise this alias.
For example: ['millert', 'mikef']

##### <a name="-sudo--alias--user--comment"></a>`comment`

Data type: `Optional[String[1]]`

Textual comment for this entry

Default value: `undef`

##### <a name="-sudo--alias--user--order"></a>`order`

Data type: `Integer`

If desired, force the order of this entry relative to other entries.
Usually not required.

Default value: `16`

### <a name="sudo--default_entry"></a>`sudo::default_entry`

Adds an entry to the defaults section of /etc/sudoers in order to override
runtime defaults. See the 'Defaults' section of sudoers(5) for more
information.

#### Examples

##### To create the following defaults line in sudoers:

```puppet
Defaults    requiretty, syslog=authpriv, !root_sudo, !umask, env_reset, env_keep = "COLORS DISPLAY HOSTNAME HISTSIZE INPUTRC KDEDIR \
                     LS_COLORS MAIL PS1 PS2 QTDIR USERNAME \
                     LANG LC_ADDRESS LC_CTYPE LC_COLLATE LC_IDENTIFICATION \
                     LC_MEASUREMENT LC_MESSAGES LC_MONETARY LC_NAME LC_NUMERIC \
                     LC_PAPER LC_TELEPHONE LC_TIME LC_ALL LANGUAGE LINGUAS \
                     _XKB_CHARSET XAUTHORITY"

Use the default_entry definition:
  sudo::default_entry { '00_main':
      content => [ 'requiretty',
          'syslog=authpriv',
          '!root_sudo',
          '!umask',
          'env_reset',
          'env_keep = "COLORS DISPLAY HOSTNAME HISTSIZE INPUTRC KDEDIR \
                       LS_COLORS MAIL PS1 PS2 QTDIR USERNAME \
                       LANG LC_ADDRESS LC_CTYPE LC_COLLATE LC_IDENTIFICATION \
                       LC_MEASUREMENT LC_MESSAGES LC_MONETARY LC_NAME LC_NUMERIC \
                       LC_PAPER LC_TELEPHONE LC_TIME LC_ALL LANGUAGE LINGUAS \
                       _XKB_CHARSET XAUTHORITY"' ]
  }
```

#### Parameters

The following parameters are available in the `sudo::default_entry` defined type:

* [`content`](#-sudo--default_entry--content)
* [`target`](#-sudo--default_entry--target)
* [`def_type`](#-sudo--default_entry--def_type)

##### <a name="-sudo--default_entry--content"></a>`content`

Data type: `Array[String[1]]`

The content of this entry.

##### <a name="-sudo--default_entry--target"></a>`target`

Data type: `Optional[String[1]]`

The user, host, etc hash is the target of the content.  Leave
as undef to not specify a target.

Default value: `undef`

##### <a name="-sudo--default_entry--def_type"></a>`def_type`

Data type: `Sudo::DefType`

May be one of:
- base => Global
- cmnd => Cmnd Entry
- host => Host Entry
- user => User Entry
- runas => Runas Entry

Default value: `'base'`

### <a name="sudo--include_dir"></a>`sudo::include_dir`

Add include directories to /etc/sudoers

#### Parameters

The following parameters are available in the `sudo::include_dir` defined type:

* [`include_dir`](#-sudo--include_dir--include_dir)
* [`tidy_include_dir`](#-sudo--include_dir--tidy_include_dir)

##### <a name="-sudo--include_dir--include_dir"></a>`include_dir`

Data type: `Stdlib::Absolutepath`

the directory to include in /etc/sudoers

##### <a name="-sudo--include_dir--tidy_include_dir"></a>`tidy_include_dir`

Data type: `Boolean`



Default value: `false`

### <a name="sudo--user_specification"></a>`sudo::user_specification`

Add a user_spec entry to /etc/sudoers in order to determine which commands
a user may run as the given user on the given host.
See the 'User Specification' section of sudoers(5) for more information.
Note that the 'Tag_Spec' entries have been explicitly noted below.

#### Examples

##### To create the following in /etc/sudoers:

```puppet
`simp, %simp_group    user2-dev1=(root) PASSWD:EXEC:SETENV: /bin/su root, /bin/su - root`
Use the user_specification definition:
  sudo::user_specification { 'default_simp':
    user_list => [ 'simp', '%simp_group' ],
    runas     => 'root',
    cmnd      => [ '/bin/su root', '/bin/su - root' ]
  }
```

#### Parameters

The following parameters are available in the `sudo::user_specification` defined type:

* [`user_list`](#-sudo--user_specification--user_list)
* [`cmnd`](#-sudo--user_specification--cmnd)
* [`host_list`](#-sudo--user_specification--host_list)
* [`runas`](#-sudo--user_specification--runas)
* [`passwd`](#-sudo--user_specification--passwd)
* [`doexec`](#-sudo--user_specification--doexec)
* [`setenv`](#-sudo--user_specification--setenv)
* [`options`](#-sudo--user_specification--options)

##### <a name="-sudo--user_specification--user_list"></a>`user_list`

Data type: `Array[String[1]]`

Array of users or groups that should be able to execute a command.
Groups must be preceded by %.

##### <a name="-sudo--user_specification--cmnd"></a>`cmnd`

Data type: `Array[String[1]]`

Should be an array of commands you wan to run.

##### <a name="-sudo--user_specification--host_list"></a>`host_list`

Data type: `Array[Simplib::Hostname,1]`

Array of hosts where the specified users should be able to execute a command.

Default value: `[$facts['networking']['hostname'], $facts['networking']['fqdn']]`

##### <a name="-sudo--user_specification--runas"></a>`runas`

Data type: `Variant[String[1],Array[String[1]]]`

Can be an array of users that you need to be able to run the commands
as.  It will probably just be one user in most cases.

Default value: `['root']`

##### <a name="-sudo--user_specification--passwd"></a>`passwd`

Data type: `Boolean`

Set PASSWD in /etc/sudoers

Default value: `true`

##### <a name="-sudo--user_specification--doexec"></a>`doexec`

Data type: `Boolean`

Set EXEC in /etc/sudoers

Default value: `true`

##### <a name="-sudo--user_specification--setenv"></a>`setenv`

Data type: `Boolean`

Set SETENV in /etc/sudoers

Default value: `true`

##### <a name="-sudo--user_specification--options"></a>`options`

Data type: `Hash`

Set additional options (such as SELinux role or type, date restrictions, or timeout)

Default value: `{}`

## Functions

### <a name="sudo--update_runas_list"></a>`sudo::update_runas_list`

Type: Ruby 4.x API

This function is used to help mitigate CVE-2019-14287 for
 sudo version prior to 1.8.28.  It will disallow userid/groupid
 of -1 if ALL or %ALL is used.

#### `sudo::update_runas_list(Array[String] $content)`

Note: Added even if !root is not present because it will skip over
some auditing if #-1 is used.

Returns: `Array[String]` An Array of users to add to a Runas_list in sudo that
appends not -1 if 'ALL' or '%ALL' are used to avoid
giving unintentional root access or skip auditing.

##### `content`

Data type: `Array[String]`

An array of users/groups to add to a Runas_list in sudo

#### `sudo::update_runas_list(String $content)`

Note: Added even if !root is not present because it will skip over
some auditing if #-1 is used.

Returns: `Array[String]` An Array of users to add to a Runas_list in sudo that
appends not -1 if 'ALL' or '%ALL' are used to avoid
giving unintentional root access or skip auditing.

##### `content`

Data type: `String`

A string of one user/group id to to Runas_list.

## Data types

### <a name="Sudo--AliasType"></a>`Sudo::AliasType`

Matches the list of configuration items for which aliases
can be set in the sudeors file.

Alias of `Enum['user', 'runas', 'host', 'cmnd']`

### <a name="Sudo--DefType"></a>`Sudo::DefType`

Matches the list configuration items for which  defaults can be set
in the sudoers file.

Alias of `Enum['base', 'cmnd', 'host', 'user', 'runas']`

